# Project Brief: slacraper

## コア要件と目標

slacraper は、Slack のメッセージを取得するためのツールです。以下の目標を持っています：

1. ライブラリとしての利用を基本とする
2. CLI としても利用可能にする
3. 特定の条件でメッセージをフィルタリングできる機能を提供する
4. 構造化された JSON 形式で出力する
5. シンプルで使いやすいインターフェースを提供する

## プロジェクト範囲

### 含まれるもの（実装済み）

- Slack API を使用したメッセージの取得機能

  - チャンネル名から自動的にチャンネル ID を解決
  - メッセージ本文の取得
  - ユーザー情報の取得
  - リアクション情報の取得
  - タイムスタンプの ISO フォーマット変換

- 多様なフィルタリングオプション

  - チャンネル名（必須）
  - ユーザー名
  - テキスト内容
  - リアクション（スタンプ）
  - 時間範囲（デフォルトは 1 時間以内）

- 柔軟なインターフェース

  - ライブラリとしての API
  - CLI インターフェース
  - 環境変数または引数からのトークン取得

- 追加機能

  - メッセージ URL の生成オプション
  - 構造化された JSON 出力
  - 適切なエラーハンドリング

- 品質保証

  - ユニットテスト（コア機能と CLI）
  - モックを使用したテスト
  - 型ヒントによるコード品質向上

- デプロイメント
  - PyPI への自動リリース設定
  - GitHub Actions による CI/CD
  - セマンティックバージョニング

### 含まれないもの

- メッセージの投稿機能
- ファイルのアップロード/ダウンロード機能
- リアルタイムのメッセージ監視機能
- GUI インターフェース
- ページネーション処理（大量メッセージ取得時）
- スレッド返信の取得
- ファイル添付の情報取得
- 出力形式のカスタマイズ（JSON 以外）

## 技術スタック

- **言語**: Python 3.12+

  - 型ヒント
  - モダンな Python 機能

- **主要ライブラリ**:

  - slack-sdk 3.0.0+: Slack API との通信
  - click 8.0.0+: CLI オプションパーサー

- **パッケージング**:

  - setuptools: パッケージビルド
  - setuptools_scm: Git タグからのバージョン管理
  - wheel: パッケージ配布形式

- **テスト**:

  - unittest: テストフレームワーク
  - unittest.mock: モッキング

- **CI/CD**:
  - GitHub Actions: 自動ビルドとデプロイ
  - PyPI: パッケージ公開

## 成果物

1. **Python パッケージ**

   - src-layout に基づく構造
   - PyPI で公開
   - pip でインストール可能

2. **CLI ツール**

   - コマンドラインから直接実行可能
   - ヘルプメッセージ付き
   - 標準出力に JSON を出力

3. **ドキュメント**

   - README.md による使用方法の説明
   - ライブラリとしての使用例
   - CLI としての使用例

4. **テストスイート**
   - コア機能のユニットテスト
   - CLI のユニットテスト
   - 高いテストカバレッジ

## 成功基準

1. **機能的基準**

   - すべての必須機能が実装されている
   - すべてのテストが成功する
   - CLI が正しく動作する
   - ライブラリ API が使いやすい

2. **非機能的基準**

   - コードが読みやすく保守しやすい
   - エラーメッセージが明確
   - パフォーマンスが許容範囲内
   - ドキュメントが充実している

3. **デプロイメント基準**
   - PyPI に公開可能
   - GitHub Actions が正しく設定されている
   - インストールと使用が容易
